@@ -1,8 +1,8 @@
 package JSON::Karabiner::Rule ;
-$JSON::Karabiner::Rule::VERSION = '0.008';
+$JSON::Karabiner::Rule::VERSION = '0.009';
 use strict;
 use warnings;
-use JSON::Karabiner::Manipulator ;
+require JSON::Karabiner::Manipulator ;
 use Carp;
 
 sub new {
@@ -35,7 +35,7 @@ sub _enable_validity_tests {
 sub add_manipulator {
   my $s = shift;
 
-  my $manip  = JSON::Karabiner::Manipulator->new($s->{manipulators});
+  my $manip  = JSON::Karabiner::Manipulator->new_manipulator();
   push @{$s->{manipulators}}, $manip;
   return $manip;
 }
@@ -64,7 +64,7 @@ Methods are listed below for reference purposes only.
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 AUTHOR
 
